@@ -7,7 +7,7 @@ use warnings;
 
 # VERSION
 
-our $VERSION = '3.18';
+our $VERSION = '3.20';
 
 # AUTHORITY
 
@@ -49,6 +49,7 @@ sub import {
     gather => 1,
     hash => 1,
     hashref => 1,
+    is_bool => 1,
     is_false => 1,
     is_true => 1,
     json => 1,
@@ -428,6 +429,12 @@ sub hashref (@) {
     : ({(scalar(@args) % 2) ? (@args, undef) : @args}));
 }
 
+sub is_bool ($) {
+  my ($data) = @_;
+
+  return type($data, 'coded', 'BOOLEAN') ? true() : false();
+}
+
 sub is_false ($) {
   my ($data) = @_;
 
@@ -996,7 +1003,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-3.18
+3.20
 
 =cut
 
@@ -1004,12 +1011,7 @@ OO Standard Library for Perl 5
 
   package main;
 
-  use Venus qw(
-    catch
-    error
-    is_true
-    raise
-  );
+  use Venus 'catch', 'error', 'raise';
 
   # error handling
   my ($error, $result) = catch {
@@ -1017,12 +1019,12 @@ OO Standard Library for Perl 5
   };
 
   # boolean keywords
-  if (is_true $result) {
+  if ($result) {
     error;
   }
 
   # raise exceptions
-  if (is_true $result) {
+  if ($result) {
     raise 'MyApp::Error';
   }
 
@@ -2525,6 +2527,73 @@ I<Since C<3.10>>
 
 =cut
 
+=head2 is_bool
+
+  is_bool(Any $arg) (Bool)
+
+The is_bool function returns L</true> if the value provided is a boolean value,
+not merely truthy, and L</false> otherwise.
+
+I<Since C<3.18>>
+
+=over 4
+
+=item is_bool example 1
+
+  package main;
+
+  use Venus 'is_bool';
+
+  my $is_bool = is_bool true;
+
+  # true
+
+=back
+
+=over 4
+
+=item is_bool example 2
+
+  package main;
+
+  use Venus 'is_bool';
+
+  my $is_bool = is_bool false;
+
+  # true
+
+=back
+
+=over 4
+
+=item is_bool example 3
+
+  package main;
+
+  use Venus 'is_bool';
+
+  my $is_bool = is_bool 1;
+
+  # false
+
+=back
+
+=over 4
+
+=item is_bool example 4
+
+  package main;
+
+  use Venus 'is_bool';
+
+  my $is_bool = is_bool 0;
+
+  # false
+
+=back
+
+=cut
+
 =head2 is_false
 
   is_false(Any $data) (Bool)
