@@ -69,7 +69,6 @@ sub arg {
   my $_type = $data->{type};
 
   require Venus::Array;
-  require Venus::Unpack;
 
   # value
   @values = @{Venus::Array->new($self->parser->unused)->range($_range // 0)};
@@ -87,23 +86,6 @@ sub arg {
     @values = ($_default);
   }
 
-  my %type_map = (
-    boolean => 'number',
-    float => 'float',
-    number => 'number',
-    string => 'string',
-    yesno => 'yesno',
-  );
-
-  # type
-  if ($_type) {
-    my ($caught, @values) = Venus::Unpack->new(args => [@values])->all->catch(
-      'validate', $type_map{$_type}
-    );
-    $self->throw('error_on_arg_validation', $caught->message, $_name, $_type)->error
-      if $caught;
-  }
-
   # return boolean values
   @values = map +(lc($_type) eq 'boolean' ? ($_ ? true : false) : $_), @values
     if $_type;
@@ -733,7 +715,6 @@ sub opt {
   my $_type = $data->{type};
 
   require Venus::Array;
-  require Venus::Unpack;
 
   my $parsed = $self->parser->get($name);
 
@@ -753,23 +734,6 @@ sub opt {
     @values = ($_default);
   }
 
-  my %type_map = (
-    boolean => 'number',
-    float => 'float',
-    number => 'number',
-    string => 'string',
-    yesno => 'yesno',
-  );
-
-  # type
-  if ($_type) {
-    my ($caught, @values) = Venus::Unpack->new(args => [@values])->all->catch(
-      'validate', $type_map{$_type}
-    );
-    $self->throw('error_on_opt_validation', $caught->message, $_name, $_type)->error
-      if $caught;
-  }
-
   # return boolean values
   @values = map +(lc($_type) eq 'boolean' ? ($_ ? true : false) : $_), @values
     if $_type;
@@ -808,6 +772,12 @@ sub parser {
   return Venus::Opts->new(value => $self->data, specs => $self->spec);
 }
 
+sub pass {
+  my ($self, $method, @args) = @_;
+
+  return $self->exit(0, $method, @args);
+}
+
 sub set {
   my ($self, $key, $name, $data) = @_;
 
@@ -1161,6 +1131,40 @@ sub str {
   return $self->get_str($name);
 }
 
+sub test {
+  my ($self, $key, $name) = @_;
+
+  my @values = $self->$key($name);
+
+  my $data = $self->get($key, $name);
+
+  my $type = $data->{type} || 'boolean';
+
+  my %type_map = (
+    boolean => 'number',
+    float => 'float',
+    number => 'number',
+    string => 'string',
+    yesno => 'yesno',
+  );
+
+  require Venus::Assert;
+
+  if ($type) {
+    for (my $i = 0; $i < @values; $i++) {
+      my $assert = Venus::Assert->new("at index $i")->expression(
+        $type_map{$type}
+      );
+      if (my $caught = $assert->catch('validate', $values[$i])) {
+        my $error = "error_on_${key}_validation";
+        $self->throw($error, $caught->message, $name, $type)->error;
+      }
+    }
+  }
+
+  return wantarray ? (@values) : [@values];
+}
+
 # ROUTINES
 
 sub _wrap_text {
@@ -1448,29 +1452,6 @@ I<Since C<2.55>>
 
 =back
 
-=over 4
-
-=item arg example 7
-
-  package main;
-
-  use Venus::Cli;
-
-  my $cli = Venus::Cli->new(['--help']);
-
-  $cli->set('arg', 'name', {
-    type => 'string',
-    range => '0',
-  });
-
-  my ($name) = $cli->arg('name');
-
-  # Exception! (isa Venus::Cli::Error) (see error_on_arg_validation)
-
-  # Invalid argument: name: received (undef), expected (string)
-
-=back
-
 =cut
 
 =head2 cmd
@@ -2281,29 +2262,6 @@ I<Since C<2.55>>
 
 =back
 
-=over 4
-
-=item opt example 7
-
-  package main;
-
-  use Venus::Cli;
-
-  my $cli = Venus::Cli->new(['example', '--name', 'example']);
-
-  $cli->set('opt', 'name', {
-    type => 'number',
-    multi => 1,
-  });
-
-  my ($name) = $cli->opt('name');
-
-  # Exception! (isa Venus::Cli::Error) (see error_on_opt_validation)
-
-  # Invalid option: name: received (undef), expected (number)
-
-=back
-
 =cut
 
 =head2 parsed
@@ -2373,6 +2331,45 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 pass
+
+  pass(Str|CodeRef $code, Any @args) (Any)
+
+The pass method exits the program with the exit code C<0>. Optionally, you can
+dispatch before exiting by providing a method name or coderef, and arguments.
+
+I<Since C<3.10>>
+
+=over 4
+
+=item pass example 1
+
+  # given: synopsis
+
+  package main;
+
+  my $pass = $cli->pass;
+
+  # ()
+
+=back
+
+=over 4
+
+=item pass example 2
+
+  # given: synopsis
+
+  package main;
+
+  my $pass = $cli->pass('stash', 'executed', 1);
+
+  # ()
+
+=back
+
+=cut
+
 =head2 set
 
   set(Str $type, Str $name, Str|HashRef $data) (Any)
@@ -2600,6 +2597,105 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 test
+
+  test(Str $type, Str $name) (Any)
+
+The test method validates the values for the C<arg> or C<opt> specified and
+returns the value(s) associated. If validation failed an exception is thrown.
+
+I<Since C<3.10>>
+
+=over 4
+
+=item test example 1
+
+  package main;
+
+  use Venus::Cli;
+
+  my $cli = Venus::Cli->new(['help']);
+
+  $cli->set('arg', 'name', {
+    type => 'string',
+    range => '0',
+  });
+
+  my ($name) = $cli->test('arg', 'name');
+
+  # "help"
+
+=back
+
+=over 4
+
+=item test example 2
+
+  package main;
+
+  use Venus::Cli;
+
+  my $cli = Venus::Cli->new(['--help']);
+
+  $cli->set('arg', 'name', {
+    type => 'string',
+    range => '0',
+  });
+
+  my ($name) = $cli->test('arg', 'name');
+
+  # Exception! (isa Venus::Cli::Error) (see error_on_arg_validation)
+
+  # Invalid argument: name: received (undef), expected (string)
+
+=back
+
+=over 4
+
+=item test example 3
+
+  package main;
+
+  use Venus::Cli;
+
+  my $cli = Venus::Cli->new(['example', '--name', 'example']);
+
+  $cli->set('opt', 'name', {
+    type => 'string',
+    multi => 1,
+  });
+
+  my ($name) = $cli->test('opt', 'name');
+
+  # "example"
+
+=back
+
+=over 4
+
+=item test example 4
+
+  package main;
+
+  use Venus::Cli;
+
+  my $cli = Venus::Cli->new(['example', '--name', 'example']);
+
+  $cli->set('opt', 'name', {
+    type => 'number',
+    multi => 1,
+  });
+
+  my ($name) = $cli->test('opt', 'name');
+
+  # Exception! (isa Venus::Cli::Error) (see error_on_opt_validation)
+
+  # Invalid option: name: received (undef), expected (number)
+
+=back
+
+=cut
+
 =head1 ERRORS
 
 This package may raise the following errors:
