@@ -72,4 +72,19 @@ Unacceptable Role for Perl 5
 This package provides a mechanism for raising an exception when unexpected
 constructor arguments are encountered.
 
+=cut
+
+=head1 AUTHORS
+
+Awncorp, C<awncorp@cpan.org>
+
+=cut
+
+=head1 LICENSE
+
+Copyright (C) 2000, Al Newkirk.
+
+This program is free software, you can redistribute it and/or modify it under
+the terms of the Apache license version 2.0.
+
 =cut
\ No newline at end of file
