@@ -199,19 +199,36 @@ state $init = {
   exec => {
     brew => 'perlbrew',
     cpan => 'cpanm -llocal -qn',
-    deps => 'cpan --installdeps .',
-    each => '$PERL -MVenus=true,false,log -nE',
-    eval => '$PERL -MVenus=true,false,log -E',
+    docs => 'perldoc',
+    each => 'shim -nE',
+    edit => '$EDITOR $VENUS_FILE',
+    eval => 'shim -E',
     exec => '$PERL',
     info => '$PERL -V',
     lint => 'perlcritic',
     okay => '$PERL -c',
     repl => '$PERL -dE0',
-    reup => 'cpan Venus',
+    reup => 'cpanm -qn Venus',
     says => 'eval "map log(eval), @ARGV"',
-    step => 'eval "while(<>){log(eval)}"',
+    shim => '$PERL -MVenus=true,false,log',
+    test => '$PROVE',
     tidy => 'perltidy',
-    test => '$PROVE'
+  },
+  flow => {
+    deps => [
+      'cpan Perl::Critic',
+      'cpan Perl::Tidy',
+      'cpan Pod::Perldoc',
+    ],
+    prep => [
+      'deps',
+      'reqs',
+    ],
+    reqs => [
+      'which perlcritic',
+      'which perldoc',
+      'which perltidy',
+    ],
   },
   libs => [
     '-Ilib',
@@ -290,7 +307,7 @@ sub _find {
 
   @data = map _split($_), @data;
 
-  my @item = map {s/^\$//r} shift @data;
+  my @item = shift @data;
 
   @item = (_find_in_exec($seen, $conf, @item));
 
@@ -537,9 +554,9 @@ sub _make {
 sub _prep {
   my ($conf, @data) = @_;
 
-  my @args = map _vars($_), grep defined, _make($conf, shift(@data)), @data;
+  my @args = grep defined, _make($conf, shift(@data)), @data;
 
-  my $prog = shift @args;
+  my $prog = _vars(shift(@args));
 
   require Venus::Os;
 
@@ -559,7 +576,8 @@ sub _prep {
     if ($args[$i] =~ /^\d[<>&]+\d?$/) {
       next;
     }
-    if ($args[$i] =~ /\$[A-Z]\w+/) {
+    if ($args[$i] =~ /^\$[A-Z]\w+$/) {
+      $args[$i] = _vars($args[$i]);
       next;
     }
     if ($args[$i] =~ /^\$\((.*)\)$/) {
@@ -628,7 +646,7 @@ sub _set_vars {
   }
 
   if (my $vars = $conf->{vars}) {
-    $ENV{$_} = join(' ', grep defined, _find({}, $conf, $_)) for keys %{$vars};
+    $ENV{$_} = join(' ', grep defined, @{_prep($conf, $_)}) for keys %{$vars};
   }
 
   if (my $asks = $conf->{asks}) {
@@ -1205,7 +1223,7 @@ I<Since C<2.91>>
   #
   # ...
 
-  my $run = Venus::Run->new(['deps']);
+  my $run = Venus::Run->new(['cpan', '--installdeps', '.']);
 
   $run->execute;
 
@@ -1673,24 +1691,41 @@ I<Since C<2.91>>
   #   exec => {
   #     brew => 'perlbrew',
   #     cpan => 'cpanm -llocal -qn',
-  #     deps => 'cpan --installdeps .',
-  #     each => '$PERL -MVenus=true,false,log -nE',
-  #     eval => '$PERL -MVenus=true,false,log -E',
+  #     docs => 'perldoc',
+  #     each => 'shim -nE',
+  #     edit => '$EDITOR $VENUS_FILE',
+  #     eval => 'shim -E',
   #     exec => '$PERL',
   #     info => '$PERL -V',
+  #     lint => 'perlcritic',
   #     okay => '$PERL -c',
   #     repl => '$PERL -dE0',
-  #     says => 'eval "map log($_), map eval, @ARGV"',
-  #     test => '$PROVE'
+  #     reup => 'cpanm -qn Venus',
+  #     says => 'eval "map log(eval), @ARGV"',
+  #     shim => '$PERL -MVenus=true,false,log',
+  #     test => '$PROVE',
+  #     tidy => 'perltidy',
   #   },
-  #   find => {
+  #   flow => {
+  #     deps => [
+  #       'cpan Perl::Critic',
+  #       'cpan Perl::Tidy',
+  #       'cpan Pod::Perldoc',
+  #     ],
+  #     prep => [
+  #       'deps',
+  #       'reqs',
+  #     ],
+  #     reqs => [
+  #       'which perlcritic',
+  #       'which perldoc',
+  #       'which perltidy',
+  #     ],
   #   },
   #   libs => [
   #     '-Ilib',
   #     '-Ilocal/lib/perl5',
   #   ],
-  #   load => [
-  #   ],
   #   path => [
   #     './bin',
   #     './dev',
@@ -1699,10 +1734,6 @@ I<Since C<2.91>>
   #   perl => {
   #     perl => 'perl',
   #     prove => 'prove',
-  #     'perl-5.18.0' => 'perlbrew exec --with perl-5.18.0 perl',
-  #     'prove-5.18.0' => 'perlbrew exec --with perl-5.18.0 prove'
-  #   },
-  #   task => {
   #   },
   #   vars => {
   #     PERL => 'perl',
@@ -1819,13 +1850,10 @@ C<.vns.yaml>.
   data:
     ECHO: true
   exec:
-    okay: $PERL -c
     cpan: cpanm -llocal -qn
-    deps: cpan --installdeps .
-    each: $PERL -MVenus=log -nE
-    exec: $PERL -MVenus=log -E
+    okay: $PERL -c
     repl: $PERL -dE0
-    says: exec "map log(\$_), map eval, \@ARGV"
+    says: $PERL -E "map log(eval), @ARGV"
     test: $PROVE
   libs:
   - -Ilib
@@ -2070,32 +2098,38 @@ L<vns> CLI, which is simply an executable file which loads this package.
   # Install a distribution
   vns cpan $DIST
 
-  i.e. cpanm --llocal -qn $DIST
+  # i.e.
+  # cpanm --llocal -qn $DIST
 
   # Install dependencies in the CWD
   vns deps
 
-  i.e. cpanm --llocal -qn --installdeps .
+  # i.e.
+  # cpanm --llocal -qn --installdeps .
 
   # Check that a package can be compiled
   vns okay $FILE
 
-  i.e. perl -Ilib -Ilocal/lib/perl5 -c $FILE
+  # i.e.
+  # perl -Ilib -Ilocal/lib/perl5 -c $FILE
 
   # Use the Perl debugger as a REPL
   vns repl
 
-  i.e. perl -Ilib -Ilocal/lib/perl5 -dE0
+  # i.e.
+  # perl -Ilib -Ilocal/lib/perl5 -dE0
 
   # Evaluate arbitrary Perl expressions
   vns exec ...
 
-  i.e. perl -Ilib -Ilocal/lib/perl5 -MVenus=log -E $@
+  # i.e.
+  # perl -Ilib -Ilocal/lib/perl5 -MVenus=log -E $@
 
   # Test the Perl project in the CWD
   vns test t
 
-  i.e. prove -Ilib -Ilocal/lib/perl5 t
+  # i.e.
+  # prove -Ilib -Ilocal/lib/perl5 t
 
 =back
 
